<?php

//---T-H-I-S---S-C-R-P-I-T-------C-O-D-E-D-----B-Y----C-O-D-E-C-U-T-E-R------//

function sendOTP($mobile) {
    $url = "https://apix.rabbitholebd.com/appv2/login/requestOTP";
    $headers = getHeaders();
    $data = json_encode(["mobile" => $mobile]);
    return makeRequest($url, $headers, $data);
}

function loginUser($mobile, $otp) {
    $url = "https://apix.rabbitholebd.com/appv2/login";
    $headers = getHeaders();
    $data = json_encode(["mobile" => $mobile, "otp" => $otp]);
    $response = makeRequest($url, $headers, $data);
    saveUserDetails($response);
    return $response;
}

function logoutUser() {
    $file = 'codtce_secured/_userdetails';
    if (file_exists($file)) {
        unlink($file);
    }
}

function getUserDetails() {
    $file = 'codtce_secured/_userdetails';
    if (file_exists($file)) {
        $data = file_get_contents($file);
        return json_decode($data, true);
    }
    return null;
}

function getAuthorizationTokens() {
    $details = getUserDetails();
    if ($details) {
        return [
            'token' => $details['token'],
            'refreshToken' => $details['refreshToken']
        ];
    }
    return null;
}

function saveUserDetails($data) {
    $folder = 'codtce_secured';
    if (!is_dir($folder)) {
        mkdir($folder, 0700, true);
    }
    createHtaccess($folder);
    file_put_contents($folder . '/_userdetails', $data);
}

function createHtaccess($folder) {
    $htaccessPath = $folder . '/.htaccess';
    if (!file_exists($htaccessPath)) {
        $content = "deny from all\n";
        if (@file_put_contents($htaccessPath, $content) === false) {
            error_log("Failed to create .htaccess file in $folder. Please check folder permissions.");
        }
    }
}

function makeRequest($url, $headers, $data) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    curl_setopt($ch, CURLOPT_ENCODING, "gzip");
    $response = curl_exec($ch);
    curl_close($ch);
    return $response;
}

function getHeaders() {
    return [
        "current-time: " . time() * 1000,
        "hash: " . hash('sha256', uniqid()), // Replace with actual hash logic
        "user-agent: Mozilla/5.0 (Linux; Android 10; K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Mobile Safari/537.36",
        "device_type: 2",
        "content-type: application/json; charset=UTF-8",
        "accept-encoding: gzip",
    ];
}

//------------------------------------------------------------------------------------------//

function fetchLiveMatchData() {
    // Set the API URL
    $url = "https://apix.rabbitholebd.com/appv2/getFront/allChannel";

    // Set headers
    $headers = [
        "content-type: application/json",
        "x-access-token: ".getFetchedXToken(),
        "current-time: " . time() * 1000,
        "hash: ".hash('sha256', uniqid()),
        "user-agent: Mozilla/5.0 (Linux; Android 10; K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Mobile Safari/537.36",
        "device_type: 2",
        "accept-encoding: gzip"
    ];

    // Initialize cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_ENCODING, "gzip"); // Enable gzip decoding

    // Execute the request
    $response = curl_exec($ch);

    // Check for errors
    if (curl_errno($ch)) {
        return "cURL error: " . curl_error($ch);
    }

    // Decode the JSON response
    $data = json_decode($response, true);

    // Close the cURL session
    curl_close($ch);

    return $data;
}

function processChannelData($data) {
    // Set the base URL for the poster logo
    $baseUrl = "https://didbxtymavoia.cloudfront.net/cms/";

    $result = [];

    // Check if there is any live channel data
    if (!empty($data['output']['online_channel'])) {
        foreach ($data['output']['online_channel'] as $channel) {
            $channelData = [];
            // Extract required fields
            $channelId = $channel['channel_id'];
            $name = $channel['name'];
            $poster = $baseUrl . $channel['poster']; // Prepend the base URL to the poster

            // Get casting info
            $castingInfo = array_column($channel['casting_info'], 'value', 'title');
            $series = $castingInfo['Series'];
            $venue = $castingInfo['Venue'];
            $date = $castingInfo['Date'];
            $time = $castingInfo['Time'];

            $channelData = [
                'channelId' => $channelId,
                'name' => $name,
                'poster' => $poster,
                'series' => $series,
                'venue' => $venue,
                'date' => $date,
                'time' => $time
            ];

            $result['live'][] = $channelData;
        }
    } else {
        $result['live'] = "NOT AVAILABLE ANY LIVE MATCH";

        // Print upcoming_channel data
        if (!empty($data['output']['upcoming_channel'])) {
            foreach ($data['output']['upcoming_channel'] as $channel) {
                $channelData = [];
                // Extract required fields
                $channelId = $channel['channel_id'];
                $name = $channel['name'];
                $poster = $baseUrl . $channel['poster']; // Prepend the base URL to the poster

                // Get casting info
                $castingInfo = array_column($channel['casting_info'], 'value', 'title');
                $series = $castingInfo['Series'];
                $venue = $castingInfo['Venue'];
                $date = $castingInfo['Date'];
                $time = $castingInfo['Time'];

                $channelData = [
                    'channelId' => $channelId,
                    'name' => $name,
                    'poster' => $poster,
                    'series' => $series,
                    'venue' => $venue,
                    'date' => $date,
                    'time' => $time
                ];

                $result['upcoming'][] = $channelData;
            }
        } else {
            $result['upcoming'] = "No upcoming matches available.";
        }
    }

    return $result;
}

//---T-H-I-S---S-C-R-P-I-T-------C-O-D-E-D-----B-Y----C-O-D-E-C-U-T-E-R------//

function getFetchedXToken() {
    $tokens = getAuthorizationTokens();
    return $tokens['token'];
}

function getFetchedRToken() {
    $tokens = getAuthorizationTokens();
    return $tokens['refreshToken'];
}

//-------------------------------------------//


?>