<?php

include('_functions.php');

// If $WEB_PAGE is "NO", stop execution and prevent access to this page
if ($WEB_PAGE === "NO") {
    exit();  // This will stop the page from loading completely
}

// Fetch live match data
$data = fetchLiveMatchData();

// Process the data
$processedData = processChannelData($data);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RABBITHOLD PRIME - POWERED BY CODECUTER</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        /* General body styling */
        body {
            font-family: Arial, sans-serif;
            background: linear-gradient(135deg, #ff7e5f, #feb47b);
            background-size: cover;
            background-attachment: fixed;
            margin: 0;
            padding: 0;
            text-align: center;
            color: #333;
            overflow-x: hidden; /* Prevent horizontal scrolling */
        }

        header {
            background-color: #1a2a6c;
            color: #fff;
            padding: 20px 0;
            text-align: center;
            position: relative;  /* Added for positioning the icons */
        }

        .header-logo {
            display: inline-block;
        }

        .header-logo img {
            max-width: 180px;  /* Increased size from 120px to 180px */
            height: auto;
        }

        /* Position the Codtc download icon (left side) */
        .codtc-download-icon {
            position: absolute;
            top: 20px;
            left: 20px;
            width: 40px;  /* Set the size of the icon */
            height: auto;
        }

        /* Position the Codtc login icon (right side) */
        .codtc-login-icon {
            position: absolute;
            top: 20px;
            right: 20px;
            width: 40px;  /* Set the size of the icon */
            height: auto;
        }

        /* Match headings */
        .match-heading {
            font-size: 18px;  /* Reduced font size */
            font-weight: bold;
            color: #fff;
            background: #ff5722;
            padding: 10px;
            border-radius: 8px;
            margin: 20px auto;
            width: fit-content;
            text-transform: uppercase;
        }

        /* "No Live Match" Design */
        .no-live-match {
            font-size: 10px;  /* Further reduced font size */
            color: white;
            background: linear-gradient(45deg, #f39c12, #e74c3c);
            padding: 10px 20px;  /* Adjust padding as needed */
            border-radius: 8px;
            margin: 20px auto;
            font-weight: bold;
            text-transform: uppercase;
            letter-spacing: 2px;
            display: inline-block;  /* Keeps it in a single line */
            white-space: nowrap;  /* Prevent text from wrapping */
            animation: fadeInUp 1.5s ease-in-out;  /* Apply animation */
        }

        /* Keyframes for animation */
        @keyframes fadeInUp {
            0% {
                opacity: 0;
                transform: translateY(20px);
            }
            100% {
                opacity: 1;
                transform: translateY(0);
            }
        }

        /* Grid layout for match cards */
        .match-list {
            display: grid;
            grid-template-columns: repeat(2, 1fr); /* Default 2-column layout for desktops */
            gap: 20px;
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        .match-card {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            transition: transform 0.3s ease;
        }

        .match-card:hover {
            transform: scale(1.05);
        }

        /* Adjusted CSS for the poster image (larger size) */
        .match-card img {
            width: 100%;          /* Ensure the image takes the full width */
            height: auto;         /* Maintain aspect ratio */
            object-fit: contain;  /* Ensures the entire image is shown within the container */
            max-width: 400px;     /* Increased size from 300px to 400px */
            margin: 0 auto;       /* Center the image */
        }

        .match-card .details {
            padding: 15px;
        }

        .match-card .details h2 {
            font-size: 10px;  /* Further reduced font size for name */
            color: #333;
        }

        .match-card .details p {
            font-size: 8px;  /* Further reduced font size for series, venue, date, and time */
            color: #666;
            margin: 5px 0;
        }

        /* Responsive Design: Adjust for mobile devices */
        @media (max-width: 1024px) {
            .match-list {
                grid-template-columns: repeat(2, 1fr); /* 2-column layout on tablets */
            }
        }

        @media (max-width: 768px) {
            .match-list {
                grid-template-columns: repeat(2, 1fr); /* Force 2-column layout on tablets and smaller devices */
            }
        }

        @media (max-width: 480px) {
            .header-logo img {
                max-width: 120px; /* Keep logo a bit smaller on small screens */
            }

            .no-live-match {
                font-size: 12px; /* Reduced font size for smaller screens */
            }

            .match-heading {
                font-size: 18px; /* Smaller heading on mobile */
            }

            .match-list {
                grid-template-columns: repeat(2, 1fr); /* Ensuring 2 columns even on mobile */
            }
        }
    </style>
</head>
<body>
    <header>
        <div class="header-logo">
            <img src="https://i.postimg.cc/wBtdxcV8/image.webp" alt="Website Logo">
        </div>
        <a href="playlist.php">
            <img class="codtc-download-icon" src="https://i.postimg.cc/k5KJZ7Sr/codtc-download.png" alt="Codtc Download">
        </a>
        <a href="login.php">
            <img class="codtc-login-icon" src="https://i.postimg.cc/Rh8LN1Zn/Codtc-login.png" alt="Codtc Login">
        </a>
    </header>

    <div class="container">
        <section>
            <div class="match-heading live-heading">
                Live Matches
            </div>
            <div class="match-list">
                <?php if (is_array($processedData['live'])): ?>
                    <?php foreach ($processedData['live'] as $match): ?>
                        <div class="match-card">
                            <a href="Play.php?c=<?php echo $match['channelId']; ?>">
                                <img src="<?php echo $match['poster']; ?>" alt="Poster">
                            </a>
                            <div class="details">
                                <h2><?php echo $match['name']; ?></h2>
                                <p><strong>Series:</strong> <?php echo $match['series']; ?></p>
                                <p><strong>Venue:</strong> <?php echo $match['venue']; ?></p>
                                <p><strong>Date:</strong> <?php echo $match['date']; ?></p>
                                <p><strong>Time:</strong> <?php echo $match['time']; ?></p>
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="no-live-match">
                        NOT AVAILABLE ANY LIVE MATCH
                    </div>
                <?php endif; ?>
            </div>
        </section>

        <section>
            <div class="match-heading upcoming-heading">
                Upcoming Matches
            </div>
            <div class="match-list">
                <?php if (is_array($processedData['upcoming'])): ?>
                    <?php foreach ($processedData['upcoming'] as $match): ?>
                        <div class="match-card">
                            <a href="Play.php?c=<?php echo $match['channelId']; ?>">
                                <img src="<?php echo $match['poster']; ?>" alt="Poster">
                            </a>
                            <div class="details">
                                <h2><?php echo $match['name']; ?></h2>
                                <p><strong>Series:</strong> <?php echo $match['series']; ?></p>
                                <p><strong>Venue:</strong> <?php echo $match['venue']; ?></p>
                                <p><strong>Date:</strong> <?php echo $match['date']; ?></p>
                                <p><strong>Time:</strong> <?php echo $match['time']; ?></p>
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="no-live-match">
                        NO UPCOMING MATCHES
                    </div>
                <?php endif; ?>
            </div>
        </section>
    </div>
</body>
</html>