<?php
include '_functions.php';
session_start();

$secure_file_path = 'codtce_secured/_codsecured';

function get_credentials_from_file() {
    global $secure_file_path;
    if (file_exists($secure_file_path)) {
        $credentials = file_get_contents($secure_file_path);
        $lines = explode("\n", $credentials);
        $username = '';
        $password = '';
        foreach ($lines as $line) {
            if (strpos($line, 'username: ') === 0) {
                $username = trim(substr($line, strlen('username: ')));
            }
            if (strpos($line, 'password: ') === 0) {
                $password = trim(substr($line, strlen('password: ')));
            }
        }
        return ['username' => $username, 'password' => $password];
    }
    return ['username' => '', 'password' => ''];
}

if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header("Location: dashboard.php");
    exit;
}

$page = 'send_otp';
$credentials = get_credentials_from_file();
$valid_username = $credentials['username'];
$valid_password = $credentials['password'];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['send_otp'])) {
        $mobile = $_POST['mobile'];
        $response = sendOTP($mobile);
        if ($response) {
            $page = 'login';
            $mobileNumber = $mobile;
        } else {
            $error = "Failed to send OTP. Please try again.";
        }
    } elseif (isset($_POST['login'])) {
        $mobile = $_POST['mobile'];
        $otp = $_POST['otp'];
        $response = loginUser($mobile, $otp);
        $data = json_decode($response, true);
        if ($data['status'] === 'success') {
            header("Location: index.php");
            exit;
        } else {
            $page = 'login';
            $mobileNumber = $mobile;
            $error = $data['message'];
        }
    } elseif (isset($_POST['logout'])) {
        logoutUser();
        $success = "Logged out successfully!";
        $page = 'send_otp';
    }

    if (isset($_POST['change_credentials'])) {
        $new_username = $_POST['new_username'];
        $new_password = $_POST['new_password'];
        $credentials = "username: $new_username\npassword: $new_password";
        if (file_put_contents($secure_file_path, $credentials)) {
            $success = "Username and Password updated successfully!";
        } else {
            $error = "Failed to save credentials. Please try again.";
        }
        $valid_username = $new_username;
        $valid_password = $new_password;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RABBITHOLD USER LOGIN - POWERED BY CODECUTER</title>
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&display=swap" rel="stylesheet">
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>
    <style>
        body {
            margin: 0;
            padding: 0;
            font-family: 'Poppins', sans-serif;
            background: linear-gradient(135deg, #6a11cb 0%, #2575fc 100%);
            height: 100vh;
            display: flex;
            justify-content: center;
            align-items: center;
            color: #fff;
        }

        .login-container {
            background: rgba(0, 0, 0, 0.6);
            border-radius: 15px;
            padding: 30px;
            box-shadow: 0 8px 15px rgba(0, 0, 0, 0.3);
            text-align: center;
            width: 100%;
            max-width: 400px;
        }

        .user-login-title {
            font-size: 28px;
            font-weight: bold;
            letter-spacing: 2px;
            margin-bottom: 20px;
        }

        .login-container input {
            width: 100%;
            padding: 10px;
            margin: 10px 0;
            border: none;
            border-radius: 5px;
            background: #fff;
            color: #333;
        }

        .login-container button {
            padding: 10px 20px;
            margin-top: 10px;
            border: none;
            border-radius: 5px;
            background-color: #4caf50;
            color: #fff;
            font-size: 16px;
            cursor: pointer;
            transition: background 0.3s ease;
        }

        .login-container button:hover {
            background-color: #45a049;
        }

        .change-credentials {
            margin-top: 20px;
            text-align: left;
            background: rgba(255, 255, 255, 0.1);
            padding: 15px;
            border-radius: 8px;
        }

        .change-credentials input {
            background: #eee;
            color: #333;
        }

        .logout-button {
            background-color: #ff4d4d;
        }

        .logout-button:hover {
            background-color: #e04343;
        }

        .error, .success {
            margin-top: 10px;
            font-size: 14px;
        }

        /* Mobile number input style */
        .input-group {
            display: flex;
            align-items: center;
        }

        .input-group input {
            width: 100%;
            padding-left: 50px; /* Add space for the +880 */
        }

        .input-group span {
            position: absolute;
            left: 10px;
            padding: 10px;
            background-color: #fff;
            color: #333;
            font-weight: bold;
            border-radius: 5px;
        }
    </style>
</head>
<body>
<div class="login-container">
    <h1 class="user-login-title"><?php echo ($page === 'send_otp') ? "USER LOGIN" : "Login with OTP"; ?></h1>

    <?php if (!empty($error)): ?>
        <p class="error"><?php echo $error; ?></p>
    <?php endif; ?>

    <?php if (!empty($success)): ?>
        <p class="success"><?php echo $success; ?></p>
    <?php endif; ?>

    <div class="change-credentials">
        <h3>Change Username / Password</h3>
        <form method="POST">
            <input type="text" id="new_username" name="new_username" placeholder="Enter new username" required>
            <input type="password" id="new_password" name="new_password" placeholder="Enter new password" required>
            <button type="submit" name="change_credentials">Change Credentials</button>
        </form>
    </div>

    <?php if ($page === 'send_otp'): ?>
        <form method="POST">
            <div class="input-group">
                <input type="text" id="mobile" name="mobile" value="+880" placeholder="Enter your mobile number" required>
            </div>
            <button type="submit" name="send_otp">SEND OTP</button>
        </form>
    <?php elseif ($page === 'login'): ?>
        <form method="POST">
            <input type="text" id="mobile" name="mobile" value="<?php echo htmlspecialchars($mobileNumber ?? ''); ?>" readonly required>
            <input type="text" id="otp" name="otp" placeholder="Enter OTP" required>
            <button type="submit" name="login">Login</button>
        </form>
    <?php endif; ?>

    <form method="POST">
        <button type="submit" name="logout" class="logout-button">Logout</button>
    </form>
</div>
</body>
</html>