<?php

include '_functions.php';

header("Access-Control-Allow-Origin: *");
    
$id = ""; $chunks = ""; $segment = "";

// Input validation
if (isset($_REQUEST['id'])) {
    $id = trim(strip_tags($_REQUEST['id']));
}
if (isset($_REQUEST['chunks'])) {
    $chunks = trim(strip_tags($_REQUEST['chunks']));
}
if (isset($_REQUEST['segment'])) {
    $segment = trim(strip_tags($_REQUEST['segment']));
}

// Check referer based on REFER_SECURITY setting
if ($REFER_SECURITY == "YES") {
    // Require Referer
    if (empty($_SERVER['HTTP_REFERER']) || $_SERVER['HTTP_REFERER'] != $coderef) {
        echo "forbidden";
        exit();
    }
}

// Fetch stream data and cookie token
$streamingURL = fetchStreamData($id);
$cfStreamToken = fetchCookieData($id);

// Custom headers for requests
$actionHeader = [
    "Origin: https://www.rabbitholebd.com",
    "Referer: https://www.rabbitholebd.com/",
    "Cookie: " . fetch_token(),
    "User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36"
];

// Main processing logic
if (!empty($chunks)) {
    // Decrypt and validate the chunks URL
    $actionURL = encdec('decrypt', $chunks);
    if (!filter_var($actionURL, FILTER_VALIDATE_URL)) {
        http_response_code(400);
        exit("Invalid chunks URL");
    }

    $fetch = customGETRequest_fGet($actionURL, $actionHeader);
    $response = $fetch['data'];

    if (stripos($response, "#EXTM3U") !== false) {
        $kine = processM3U8Playlist($fetch);
        //header("Content-Type: application/x-mpegURL");
        echo trim($kine);
        exit();
    }
} elseif (!empty($segment)) {
    // Decrypt and validate the segment URL
    $actionURL = encdec('decrypt', $segment);
    if (!filter_var($actionURL, FILTER_VALIDATE_URL)) {
        http_response_code(400);
        exit("Invalid segment URL");
    }

    $fetch = customGETRequest_fGet($actionURL, $actionHeader);
    $response = $fetch['data'];
    header("Content-Type: video/mp2t");
    echo $response;
    exit();
} else {
    // Fetch the main M3U8 URL
    if (empty($streamingURL)) {
        http_response_code(404);
        exit("Streaming URL not found");
    }

    if ($VSTREAM_PROXY === "OFF") {
    // Fetch the raw M3U8 file
    $fetch = customGETRequest($streamingURL, $actionHeader);
    $response = $fetch['data'];

    if (!empty($response) && stripos($response, "#EXTM3U") !== false) {
        // Extract base URL from the fetched URL
        $baseURL = extract_base_url($fetch['url']);

        // Process the M3U8 file to replace relative paths with absolute URLs
        $lines = explode("\n", $response);
        $processedResponse = "";

        foreach ($lines as $line) {
            if (stripos($line, ".m3u8") !== false || stripos($line, ".ts") !== false) {
                // Replace relative file paths with absolute URLs
                $processedResponse .= $baseURL . $line . "\n";
            } else {
                // Retain non-file path lines as-is
                $processedResponse .= $line . "\n";
            }
        }

        // Return the processed M3U8 content
        header("Content-Type: application/x-mpegURL");
        echo trim($processedResponse);
        exit();
    } else {
        http_response_code(503);
        exit("Failed to fetch streaming data");
    }
} else {
        // Process the M3U8 file through the proxy
        $fetch = customGETRequest($streamingURL, $actionHeader);
        $response = $fetch['data'];
        if (stripos($response, "#EXTM3U") !== false) {
            $kine = processM3U8Playlist($fetch);
            header("Content-Type: application/x-mpegURL");
            echo trim($kine);
            exit();
        }
    }
    http_response_code(503);
    exit("Service unavailable");
}

// Helper functions
function fetch_token()
{
    global $cfStreamToken;
    return $cfStreamToken;
}

function processM3U8Playlist($fetch)
{
    $response = $fetch['data'];
    $lines = explode("\n", $response);
    $result = "";

    foreach ($lines as $line) {
        if (stripos($line, ".m3u8") !== false) {
            $baseURL = extract_base_url($fetch['url']);
            $result .= getCurrentFileName() . "?chunks=" . encdec('encrypt', $baseURL . $line) . "\n";
        } elseif (stripos($line, ".ts") !== false) {
            $baseURL = extract_base_url($fetch['url']);
            $result .= getCurrentFileName() . "?segment=" . encdec('encrypt', $baseURL . $line) . "\n";
        } else {
            $result .= $line . "\n";
        }
    }
    return $result;
}

function getCurrentFileName()
{
    return basename($_SERVER['PHP_SELF']);
}

function encdec($action, $data)
{
    $output = "";
    $key = "gZMIykISz1cnd81R";
    $iv = "q4M9Y7X8vGPkP81p";

    if ($action === "encrypt") {
        $encrypted = openssl_encrypt($data, "AES-128-CBC", $key, OPENSSL_RAW_DATA, $iv);
        $output = $encrypted ? bin2hex($encrypted) : "";
    } elseif ($action === "decrypt") {
        if (strlen($data) % 2 === 0) {
            $binary = hex2bin($data);
            $output = openssl_decrypt($binary, "AES-128-CBC", $key, OPENSSL_RAW_DATA, $iv);
        }
    }
    return $output;
}

function extract_base_url($url)
{
    $parsedUrl = parse_url($url);
    return isset($parsedUrl['scheme'], $parsedUrl['host']) ?
        $parsedUrl['scheme'] . "://" . $parsedUrl['host'] . dirname($parsedUrl['path']) . "/" :
        "";
}

function customGETRequest($url, $headers = [])
{
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_TIMEOUT, 20);
    $response = curl_exec($ch);
    $info = curl_getinfo($ch);
    $error = curl_error($ch);
    curl_close($ch);

    return [
        'url' => $info['url'] ?? $url,
        'code' => $info['http_code'] ?? 0,
        'content_type' => $info['content_type'] ?? null,
        'error' => $error,
        'data' => $response
    ];
}

function customGETRequest_fGet($url, $headers = [])
{
    $contextOptions = [
        'http' => [
            'method' => 'GET',
            'header' => implode("\r\n", $headers),
            'timeout' => 20
        ]
    ];
    $context = stream_context_create($contextOptions);
    $response = @file_get_contents($url, false, $context);

    if ($response === false) {
        $error = error_get_last();
        return ['url' => $url, 'code' => null, 'content_type' => null, 'error' => $error, 'data' => null];
    }

    $headers = $http_response_header ?? [];
    $httpCode = null;
    $contentType = null;

    foreach ($headers as $header) {
        if (stripos($header, "Content-Type:") === 0) {
            $contentType = trim(substr($header, 13));
        } elseif (preg_match('/HTTP\/\d\.\d\s+(\d+)/', $header, $matches)) {
            $httpCode = $matches[1];
        }
    }

    return ['url' => $url, 'code' => $httpCode, 'content_type' => $contentType, 'error' => null, 'data' => $response];
}

?>